"""
GraphLab offers several data structures for data analysis.

Concise descriptions of the data structures and their methods are contained in
the API documentation, along with a small number of simple examples. For more
detailed descriptions and examples, please see the `User Guide
<http://www.graphlab.com/learn/userguide>`_, `API Translator
<http://www.graphlab.com/learn/translator>`_, `How-Tos
<http://www.graphlab.com/learn/how-to>`_, and data science `Gallery
<http://www.graphlab.com/learn/gallery>`_.
"""

__all__ = ['sframe', 'sarray', 'sgraph', 'sketch', 'image']

import sframe
import sarray
import sgraph
import sketch
import image
